@@ -1,4 +1,6 @@
 CACHE = {}
 BASE_URL = 'https://api.bol.com/retailer'
 DEMO_URL = 'https://api.bol.com/retailer-demo'
+SHARED_URL = 'https://api.bol.com/shared'
+SHARED_DEMO_URL = 'https://api.bol.com/shared-demo'
 AUTH_URL = 'https://login.bol.com/token?grant_type=client_credentials'
\ No newline at end of file
