@@ -9,4 +9,6 @@ class Transport(BaseModel):
 
         self.transporterCode = transporterCode
         self.trackAndTrace = trackAndTrace
-        self.errors = False
\ No newline at end of file
+        
+        self.hasError = False
+        self.error = None
\ No newline at end of file
